@@ -9,9 +9,10 @@
 #include "aboutdata.h"
 #include "akregator_debug.h"
 #include "akregator_options.h"
+#include "config-akregator.h"
 #include "mainwindow.h"
 #include "trayicon.h"
-#ifdef WITH_KUSERFEEDBACK
+#if AKREGATOR_WITH_KUSERFEEDBACK
 #include "userfeedback/akregatoruserfeedbackprovider.h"
 #endif
 #include <KontactInterface/PimUniqueApplication>
@@ -20,15 +21,9 @@
 
 #include <QDBusInterface>
 
-#define HAVE_KICONTHEME __has_include(<KIconTheme>)
-#if HAVE_KICONTHEME
 #include <KIconTheme>
-#endif
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 
 namespace Akregator
 {
@@ -44,6 +39,27 @@ public:
 
     int activate(const QStringList &args, const QString &workingDir) override;
 
+    bool eventFilter(QObject *obj, QEvent *ev) override
+    {
+        // The QWindow of the the Akregator::MainWindow has been observed
+        // to be destroyed and recreated (asynchronously) during initialisation
+        // of the article viewer.  If this is detected, then ensure that the
+        // KStatusNotifierItem is informed.
+        if (ev->type() == QEvent::WinIdChange && obj == mMainWindow) {
+            setTrayIconAssociatedWindow();
+        }
+        return (false);
+    }
+
+    void setTrayIconAssociatedWindow()
+    {
+        // The 'associatedWindow' test below will be true if the window has been
+        // destroyed, because KStatusNotifierItem stores it as a QPointer.
+        if (Akregator::TrayIcon::getInstance() && !Akregator::TrayIcon::getInstance()->associatedWindow()) {
+            Akregator::TrayIcon::getInstance()->setAssociatedWindow(mMainWindow->windowHandle());
+        }
+    }
+
 private:
     Akregator::MainWindow *mMainWindow = nullptr;
 };
@@ -63,34 +79,28 @@ int Application::activate(const QStringList &args, const QString &workingDir)
             if (!parser->isSet(QStringLiteral("hide-mainwindow"))) {
                 mMainWindow->show();
             }
-            if (Akregator::TrayIcon::getInstance() && !Akregator::TrayIcon::getInstance()->associatedWindow()) {
-                Akregator::TrayIcon::getInstance()->setAssociatedWindow(mMainWindow->windowHandle());
-            }
+
+            setTrayIconAssociatedWindow();
+            installEventFilter(this);
+
             akr.call(QStringLiteral("openStandardFeedList"));
         }
 
         akr.call(QStringLiteral("handleCommandLine"), args);
     }
+
     return PimUniqueApplication::activate(args, workingDir);
 }
 } // namespace Akregator
 
 int main(int argc, char **argv)
 {
-#if HAVE_KICONTHEME
     KIconTheme::initTheme();
-#endif
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     Akregator::Application app(argc, &argv);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("akregator"));
 
-#if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
-#else // !HAVE_STYLE_MANAGER
-#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-    QApplication::setStyle(QStringLiteral("breeze"));
-#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-#endif // HAVE_STYLE_MANAGER
 
     app.setDesktopFileName(QStringLiteral("org.kde.akregator"));
     Akregator::AboutData about;
@@ -105,7 +115,7 @@ int main(int argc, char **argv)
     about.processCommandLine(cmdArgs);
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("akregator")));
 
-#ifdef WITH_KUSERFEEDBACK
+#if AKREGATOR_WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
         auto userFeedBack = new Akregator::AkregatorUserFeedbackProvider(nullptr);
         QTextStream(stdout) << userFeedBack->describeDataSources() << '\n';
@@ -113,6 +123,7 @@ int main(int argc, char **argv)
         return 0;
     }
 #endif
+
     if (!Akregator::Application::start(args)) {
         qCWarning(AKREGATOR_LOG) << "akregator is already running, exiting.";
         exit(0);
